#!/bin/sh
#	Reduces data by first tokenising it and then concatenating.
#
#	Copyright Les Hatton, 2013-.
#	Released under the GNU GPL.
#
#	Revision:	$Revision: 1.4 $
#	Date:	$Date: 2017/11/11 17:00:27 $
#-----------------------------------------
TOPDIR=.

if test ! -f uniprot_trembl.fasta
then
	echo "Protein data ............................................."
	echo "You have not downloaded the raw data uniprot_trembl.fasta."
	echo "Checking to see if the processed form is available ..."
	if test -f trembl_pairs.dat.gz
	then
		echo "Uncompressing raw data ..."
		gunzip trembl_pairs.dat.gz
	fi

	if test ! -f trembl_pairs.dat
	then
		echo "... no processed data available.  See 1-downloadDataSets.sh."
		exit
	else
		echo "The processed form trembl_pairs.dat is available.  This will be used."
	fi
else
	echo "The uniprot_trembl.fasta raw protein dataset is available."
	echo "Checking to see if the processed form is present and if not"
	echo "it will be created."
	if test -f trembl_pairs.dat.gz
	then
		echo "Uncompressing raw data ..."
		gunzip trembl_pairs.dat.gz
	fi

	if test ! -f trembl_pairs.dat
	then
		echo "Creating the raw pairs dataset trembl_pairs.dat"
		echo "This will take a while ........................"
		cat uniprot_trembl.fasta | ./tremblToTok.pl | sort -n -t',' -k1,1	 > trembl_pairs.dat
	fi
fi

if test -f swissprot_13-11.tok.gz
then
	echo "Uncompressing the swissprot_13-11 data."
	gunzip swissprot_13-11.tok.gz
fi

if test ! -f swissprot_13-11.tok
then
	echo "swissprot_13-11.tok missing for some reason"
	exit
fi

echo "Preparation of processed protein datasets completed:-"
ls -l trembl_pairs.dat swissprot_13-11.tok
echo

echo "Software data ............................................"
echo "For full reproducibility, you will have to download a lot of open source"
echo "... http://www.leshatton.org/Documents/Data_TSE-2013-08-0271_V1.0a.zip"
echo "This however should not be necessary and you can continue here"
echo "as some partially processed datasets are included in datasets.zip."
if test -f datasets.zip
then
	echo	"Uncompressing raw datasets ..."
	unzip datasets.zip
fi

echo "Preparation of processed datasets completed:-"
ls -l *.raw
echo
#
#	Finally, we will need the normaliser.
#
if test ! -f normalise
then
	cc -o normalise normalise.c
fi

echo "You may now continue with the processing stages, 3-xxxx.sh for each figure"
echo "shown in the Main Paper and the Supplementary Materials."
