#!/bin/bash
#
#	Finds the Kingdom length distributions from SwissProt.
#
#	Copyright Les Hatton, 2013-.
#	Released under the GNU GPL.
#
#	Revision:	$Revision: 1.2 $
#	Date:	$Date: 2015/04/13 16:09:14 $
#-------------------------------------------------------------------------
if test $# -ne 1
then
	echo "Usage: $0 [ARCHAEA|BACTERIA|EUKARYOTA|VIRUSES]"
	exit
fi

MEGATOK=swissprot_13-11.tok

if test ! -f $MEGATOK
then
	echo "$MEGATOK missing for some reason."
	exit
fi

KING=$1

echo "#x, y"									> ${KING}_swissprot_length_distribution.dat
cat $MEGATOK | grep "$KING" | awk 'BEGIN{FS=","}{print $3;}' \
	| sort -n | uniq -c | awk '{print $2, $1;}'		>> ${KING}_swissprot_length_distribution.dat
echo											>> ${KING}_swissprot_length_distribution.dat

echo "#x, y"									> ${KING}_swissprot_length_cdf.dat
cat $MEGATOK | grep "$KING" | awk 'BEGIN{FS=","}{print $3;}' \
	| sort -n |  uniq -c | ./normalise ccdf			>> ${KING}_swissprot_length_cdf.dat
echo											>> ${KING}_swissprot_length_cdf.dat

cat  AAAA_swissprot_length_distribution.gnu \
	| sed 's/AAAA/'"${KING}"'/g'					> temp$$.gnu

gnuplot	temp$$.gnu

cat  AAAA_swissprot_length_logdistribution.gnu \
	| sed 's/AAAA/'"${KING}"'/g'					> temp$$.gnu

gnuplot	temp$$.gnu

cat  AAAA_swissprot_length_cdf.gnu \
	| sed 's/AAAA/'"${KING}"'/g'					> temp$$.gnu

gnuplot	temp$$.gnu


rm -f 	temp$$.gnu


#---------------------------------------------------------------------
#	Plot the data.
#---------------------------------------------------------------------

exit
